@@ -1,16 +1,17 @@
-# This is XSConfig from CPAN that uses XSLoader
+# XSLoader for perl, not miniperl
 
 # for a description of the variables, please have a look at the
 # Porting/Glossary file, or use the url:
 # http://perl5.git.perl.org/perl.git/blob/HEAD:/Porting/Glossary
 
+package XSConfig;
 package
     Config;
 use strict;
 use warnings;
-our (%Config, $VERSION);
+use vars '%Config', '$VERSION';
 
-$VERSION = '6.25_01';
+$VERSION = '6.01';
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,22 +57,29 @@ sub import {
     return;
 }
 
+sub TIEHASH {
+    bless \do{my $uv = 0;}, $_[0]; #XS Config Obj constructor
+}
 sub DESTROY { }
+sub STORE  { die "\%Config::Config is read-only\n" }
+*DELETE = *CLEAR = \*STORE; # Typeglob aliasing uses less space
 
 if (defined &DynaLoader::boot_DynaLoader) {
     require XSLoader;
     XSLoader::load(__PACKAGE__, $VERSION);
+    %Config = ();
     tie %Config, 'Config';
 } else {
     no warnings 'redefine';
     %Config:: = ();
-    undef &{$_} for qw(import DESTROY AUTOLOAD);
+    undef &{$_} for qw(import TIEHASH DESTROY AUTOLOAD STORE);
     require 'Config_mini.pl';
 }
 
 sub AUTOLOAD {
-    require 'Config_xs_heavy.pl' if defined &DynaLoader::boot_DynaLoader;
-
+    if (defined &DynaLoader::boot_DynaLoader) {
+        require 'Config_xs_heavy.pl';
+    }
     goto \&launcher unless $Config::AUTOLOAD =~ /launcher$/;
     die "&Config::AUTOLOAD failed on $Config::AUTOLOAD";
 }
